aiscalator.jupyter package — AIscalator 0.1.0 documentation

### Navigation

- ☰
- AIscalator-0.1.0 »
- aiscalator »
- aiscalator package »

Fork me on GitHub

# aiscalator.jupyter package

## Submodules

## aiscalator.jupyter.cli module

CLI module for Jupyter related commands.

`aiscalator.jupyter.cli.` `prompt_edit`(file)

  When creating a new step, if it is already defined, ask to edit instead

  Parameters: | file (str) – existing configuration file

## Module contents

### Navigation

- index
- modules |
- next |
- previous |